@@ -5,7 +5,10 @@ from .ipx800 import IPX800
 
 
 class X24D(Extension):
+    """Represent a X-24D input."""
+
     def __init__(self, ipx: IPX800, ext_number: int, input_number: int):
+        """Init the extension."""
         super().__init__(ipx, ext_type, ext_number, input_number)
         self.io_state_id = self._config["ioInput_id"][input_number - 1]
 
